pub struct DecreaseSpotPositionQuoteResult {
pub decrease_percent: u32,
pub swap_exact_in: bool,
pub swap_input_amount: u64,
pub swap_output_amount: u64,
pub required_swap_amount: u64,
pub estimated_amount: u64,
pub estimated_payable_debt: u64,
pub estimated_collateral_to_be_withdrawn: u64,
pub price_impact: f64,
}Fields
decrease_percent: u32Position decrease percentage
swap_exact_in: boolExact in or exact out swap.
swap_input_amount: u64Swap input amount.
swap_output_amount: u64Swap output amount according.
required_swap_amount: u64if swap_exact_in is false, it’s the maximum acceptable swap input amount for position decrease according to the provided slippage. if swap_exact_in is true, it’s the minimum swap output amount. This value is passed directly to the spot position modify instruction.
estimated_amount: u64Estimated total amount of the adjusted position.
estimated_payable_debt: u64Estimated value of a debt that will be repaid.
estimated_collateral_to_be_withdrawn: u64Estimated collateral that will be withdrawn from the position.
price_impact: f64Price impact in percents (100% = 1.0)