pub struct TunaSpotPositionFacade {
pub version: u16,
pub market_maker: u8,
pub position_token: u8,
pub collateral_token: u8,
pub flags: u32,
pub amount: u64,
pub loan_shares: u64,
pub loan_funds: u64,
pub entry_sqrt_price: u128,
pub lower_limit_order_sqrt_price: u128,
pub upper_limit_order_sqrt_price: u128,
}Fields
version: u16Struct version
market_maker: u8Market maker (Orca, Fusion)
position_token: u8Position token: A (LONG, B is borrowed), B (SHORT, A is borrowed)
collateral_token: u8The token used as collateral.
flags: u32Position options (unused)
amount: u64The total amount of the position in token A (long) or B (short).
The amount of shares borrowed by the user from vault B (long) or A (short).
loan_funds: u64The amount of funds borrowed by the user from vault B (long) or A (short). Doesn’t include accrued interest.
entry_sqrt_price: u128Position entry sqrt price.
lower_limit_order_sqrt_price: u128Position lower limit order sqrt price (stop loss for a LONG position).
upper_limit_order_sqrt_price: u128Position upper limit order sqrt price (take profit for a LONG position).